<?php
defined('BASEPATH') or exit('No direct script access allowed');

class About extends CI_Controller
{
    private $dataAdmin;

    function __construct()
    {
        parent::__construct();

        if (!$this->session->auth) {
            redirect(base_url("auth/login"));
        }

        $this->load->model("user_model");
        $this->load->model("about_model");

        $this->dataAdmin = $this->user_model->get(["id" => $this->session->auth['id']])->row();
    }


    public function index()
    {

        $push = [
            "pageTitle" => "About",
            "dataAdmin" => $this->dataAdmin
        ];

        $this->load->view('administrator/header', $push);
        $this->load->view('administrator/about', $push);
        $this->load->view('administrator/footer', $push);
    }

    public function json()
    {
        if ($this->dataAdmin->role == 'admin') {
            $this->load->model("datatables");
            $this->datatables->setTable("about");
            $this->datatables->setColumn([
                '<index>',
                '<button type="button" class="btn-previewimg" data-id="<get-id>" data-image="<get-image>"><div class="table-img"><img src=".././img/[default_pic=<get-image>]"></div></button>',
                '<div class="flag-box"><img class="flag-img" src="'.base_url('assets/img/gb.svg').'"><div class="flag-content"><get-title></div></div>  <div class="flag-box"><img class="flag-img" src="'.base_url('assets/img/BG.svg').'"><div class="flag-content"><get-titleBg></div></div>',
                '<div class="flag-box"><img class="flag-img" src="'.base_url('assets/img/gb.svg').'"><div class="flag-content"><get-description></div></div>  <div class="flag-box"><img class="flag-img" src="'.base_url('assets/img/BG.svg').'"><div class="flag-content"><get-descriptionBg></div></div>',
                '<div class="text-center">
                <button type="button" class="btn btn-primary btn-sm btn-edit" data-id="<get-id>" data-title="<get-title>" data-titleBg="<get-titleBg>" data-image="<get-image>" data-description="<get-description>" data-descriptionBg="<get-descriptionBg>" ><i class="fa fa-edit"></i></button>
                <button type="button" class="btn btn-danger btn-sm btn-delete" data-id="<get-id>" data-title="<get-title>"><i class="fa fa-trash"></i></button>
                </div>'
            ]);
            $this->datatables->setOrdering(["id", "title", "description", "titleBg", "descriptionBg", NULL]);
            $this->datatables->setSearchField(["title", "description", "titleBg", "descriptionBg"]);
            $this->datatables->generate();
        } else if ($this->dataAdmin->role == 'user') { 
            $this->load->model("datatables");
            $this->datatables->setTable("about");
            $this->datatables->setColumn([
                '<index>',
                '<button type="button" class="btn-previewimg" data-id="<get-id>" data-image="<get-image>"><div class="table-img"><img src=".././img/[default_pic=<get-image>]"></div></button>',
                '<div class="flag-box"><img class="flag-img" src="'.base_url('assets/img/gb.svg').'"><div class="flag-content"><get-title></div></div>  <div class="flag-box"><img class="flag-img" src="'.base_url('assets/img/BG.svg').'"><div class="flag-content"><get-titleBg></div></div>',
                '<div class="flag-box"><img class="flag-img" src="'.base_url('assets/img/gb.svg').'"><div class="flag-content"><get-description></div></div>  <div class="flag-box"><img class="flag-img" src="'.base_url('assets/img/BG.svg').'"><div class="flag-content"><get-descriptionBg></div></div>'
            ]);
            $this->datatables->setOrdering(["id", "title", "description", "titleBg", "descriptionBg", NULL]);
            $this->datatables->setSearchField(["title", "description", "titleBg", "descriptionBg"]);
            $this->datatables->generate();
        }
    }

    function insert()
    {
        $this->process();
    }

    function update($id)
    {
        $this->process("edit", $id);
    }

    private function process($action = "add", $id = 0)
    {
        $title = $this->input->post("title");
        $description = $this->input->post("description");
        $titleBg = $this->input->post("titleBg");
        $descriptionBg = $this->input->post("descriptionBg");

        if (!$title or !$titleBg or !$description or !$descriptionBg) {
            $response['status'] = FALSE;
            $response['msg'] = "Periksa kembali data yang anda masukkan";
        } else {

            $config['upload_path']          = '././img/';
            $config['allowed_types']        = 'jpeg|jpg|png|JPEG|JPG|PNG';
            $config['max_size']             = 2048;
            $config['overwrite']            = TRUE;

            $this->load->library('upload', $config);

            if ($this->upload->do_upload('userfile')) {
                $gbr = $this->upload->data();
                $gambar = $gbr['file_name'];

                $insertData = [
                    "id" => NULL,
                    "title" => $title,
                    "description" => $description,
                    "titleBg" => $titleBg,
                    "descriptionBg" => $descriptionBg,
                    "image" => $gambar,
                    "createdBy" => $this->dataAdmin->id
                ];
            } else {
                $insertData = [
                    "id" => NULL,
                    "title" => $title,
                    "description" => $description,
                    "titleBg" => $titleBg,
                    "descriptionBg" => $descriptionBg,
                    "createdBy" => $this->dataAdmin->id
                ];
            }

            $response['status'] = TRUE;

            if ($action == "add") {
                $response['msg'] = "Data berhasil ditambahkan";
                $this->about_model->post($insertData);
            } else {
                unset($insertData['id']);

                $response['msg'] = "Data berhasil diedit";
                $this->about_model->put($id, $insertData);
            }
        }

        echo json_encode($response);
    }

    function delete($id)
    {
        $response = '';
        $this->about_model->delete($id);
        if (!$this->about_model->find($id)) {
            $response = [
                'status' => TRUE,
                'msg' => "Data berhasil dihapus"
            ];
        } else {
            $response = [
                'status' => FALSE,
                'msg' => "Data gagal dihapus"
            ];
        }

        echo json_encode($response);
    }
}
