<?php
defined('BASEPATH') or exit('No direct script access allowed');

class Draws extends CI_Controller
{
    private $dataAdmin;

    function __construct()
    {
        parent::__construct();

        if (!$this->session->auth) {
            redirect(base_url("auth/login"));
        }

        $this->load->model("user_model");
        $this->load->model("draws_model");

        $this->dataAdmin = $this->user_model->get(["id" => $this->session->auth['id']])->row();
    }


    public function index()
    {

        $push = [
            "pageTitle" => "Draws",
            "dataAdmin" => $this->dataAdmin
        ];

        $this->load->view('administrator/header', $push);
        $this->load->view('administrator/draws', $push);
        $this->load->view('administrator/footer', $push);
    }

    public function json()
    {
        if ($this->dataAdmin->role == 'admin') {
            $this->load->model("datatables");
            $this->datatables->setTable("draws");

            $this->datatables->setColumn(
                [
                    '<index>',
                    '[reformat_date=<get-date>]',
                    '<get-firstprize>',
                    '<get-secondprize>',
                    '<get-thirdprize>',
                    '<get-starterprize>',
                    '<get-consolprize>',
                    '<div class="text-center"><button type="button" class="btn btn-primary btn-sm btn-edit" data-id="<get-id>" data-date="<get-date>" data-firstprize="<get-firstprize>" data-thirdprize="<get-thirdprize>" data-secondprize="<get-secondprize>" data-starterprize="<get-starterprize>" data-consolprize="<get-consolprize>" ><i class="fa fa-edit"></i></button>
                    <button type="button" class="btn btn-danger btn-sm btn-delete" data-id="<get-id>" data-date="<get-date>"><i class="fa fa-trash"></i></button></div>'
                ]
            );

            $this->datatables->setOrdering(["id", "date", "firstprize", "secondprize", "thirdprize", "starterprize", "consolprize", NULL]);
            $this->datatables->setSearchField(["date", "firstprize", "secondprize", "thirdprize","starterprize", "consolprize"]);
            $this->datatables->generate();
        } else if ($this->dataAdmin->role == 'user') {
            $this->load->model("datatables");
            $this->datatables->setTable("draws");

            $this->datatables->setColumn(
                [
                    '<index>',
                    '<get-date>',
                    '<get-firstprize>',
                    '<get-secondprize>',
                    '<get-thirdprize>',
                    '<get-starterprize>',
                    '<get-consolprize>'
                ]
            );

            $this->datatables->setOrdering(["id", "date", "firstprize", "secondprize", "thirdprize", "starterprize", "consolprize", NULL]);
            $this->datatables->setSearchField(["date", "firstprize", "secondprize", "thirdprize","starterprize", "consolprize"]);
            $this->datatables->generate();
        }
    }


    function insert()
    {
        $this->process();
    }

    function update($id)
    {
        $this->process("edit", $id);
    }

    private function process($action = "add", $id = 0)
    {
        $date = $this->input->post("date");
        $firstprize = $this->input->post("firstprize");        
        $secondprize = $this->input->post("secondprize");
        $thirdprize = $this->input->post("thirdprize");
        $starterprize = $this->input->post("starterprize");
        $consolprize = $this->input->post("consolprize");

        if (!$secondprize or !$date or !$firstprize or !$thirdprize or !$starterprize or !$consolprize) {
            $response['status'] = FALSE;
            $response['msg'] = "Periksa kembali data yang anda masukkan";
        } else {


            $insertData = [
                "id" => NULL,
                "date" => $date,
                "firstprize" => $firstprize,
                "secondprize" => $secondprize,
                "thirdprize" => $thirdprize,                
                "starterprize" => $starterprize,
                "consolprize" => $consolprize
            ];

            $response['status'] = TRUE;

            if ($action == "add") {
                $response['msg'] = "Data berhasil ditambahkan";
                $this->draws_model->post($insertData);
            } else if ($action == "edit") {
                unset($insertData['id']);

                $response['msg'] = "Data berhasil diedit";
                $this->draws_model->put($id, $insertData);
            }
        }

        echo json_encode($response);
    }

    function delete($id)
    {
        $response = '';
        $this->draws_model->delete($id);
        if (!$this->draws_model->find($id)) {
            $response = [
                'status' => TRUE,
                'msg' => "Data berhasil dihapus"
            ];
        } else {
            $response = [
                'status' => FALSE,
                'msg' => "Data gagal dihapus"
            ];
        }

        echo json_encode($response);
    }

    public function get_dates(){
        $result = $this->draws_model->get()->result();
        echo json_encode($result);
    }
}