<?php

class Draws_model extends CI_Model
{

    var $table = 'draws';
    var $column_order = array(null, 'date', 'firstprize', 'secondprize', 'thirdprize');
    var $column_search = array('date', 'firstprize', 'secondprize', 'thirdprize');
    var $order = array('date' => 'desc');

    function post($data)
    {
        $this->db->insert("draws", $data);
    }

    function get($where = array())
    {
        if ($where) {
            return $this->db->get_where("draws", $where);
        } else {
            return $this->db->get("draws");
        }
    }

    function get_data($rowperpage, $rowno)
    {
        $this->db->select('*');
        $this->db->from('draws');
        $this->db->limit($rowperpage, $rowno);
        $query = $this->db->get();

        return $query->result_array();
    }

    function get_total()
    {
        $this->db->select('count(*) as allcount');
        $this->db->from('draws');
        $query = $this->db->get();
        $result = $query->result_array();

        return $result[0]['allcount'];
    }

    public function find($id)
    {
        $result = $this->db->where('id', $id)
            ->limit(1)
            ->get('draws');

        if ($result->num_rows() > 0)
            return $result->row();
        else
            return array();
    }

    public function getbydate($date)
    {
        $result = $this->db->where('date', $date)
            ->limit(1)
            ->get('draws');

        if ($result->num_rows() > 0)
            return $result->row();
        else
            return array();
    }

    private function _get_datatables_query()
    {
        $today = date('Y-m-d');
        $this->db->select('DAYNAME(date) as day')
            ->select('date')
            ->select('firstprize')
            ->select('secondprize')
            ->select('thirdprize')
            ->where('date !=', $today)
            ->from($this->table);
        $i = 0;
        foreach ($this->column_search as $item) {
            if ($_POST['search']['value']) {
                if ($i === 0) {
                    $this->db->group_start();
                    $this->db->like($item, $_POST['search']['value']);
                } else {
                    $this->db->or_like($item, $_POST['search']['value']);
                }
                if (count($this->column_search) - 1 == $i)
                    $this->db->group_end();
            }
            $i++;
        }

        if (isset($_POST['order'])) {
            $this->db->order_by($this->column_order[$_POST['order']['0']['column']], $_POST['order']['0']['dir']);
        } else if (isset($this->order)) {
            $order = $this->order;
            $this->db->order_by(key($order), $order[key($order)]);
        }
    }

    function get_datatables()
    {
        $this->_get_datatables_query();
        if ($_POST['length'] != -1)
            $this->db->limit($_POST['length'], $_POST['start']);
        $query = $this->db->get();
        return $query->result();
    }

    function count_filtered()
    {
        $this->_get_datatables_query();
        $query = $this->db->get();
        return $query->num_rows();
    }

    public function count_all()
    {
        $today = date('Y-m-d');
        $query = $this->db->select('DAYNAME(date) as day')
            ->select('date')
            ->select('firstprize')
            ->select('secondprize')
            ->select('thirdprize')
            ->where('date !=', $today)
            ->from($this->table);
        return $this->db->count_all_results();
    }

    function put($id, $data)
    {
        $this->db->where("id", $id);
        $this->db->update("draws", $data);
    }

    function delete($id)
    {
        $this->db->delete("draws", ["id" => $id]);
    }
}